pub struct SourceContext { /* private fields */ }Expand description
Source context.
Implementations
Sourceimpl SourceContext
impl SourceContext
Sourcepub fn new(
topology_context: &TopologyContext,
component_context: &ComponentContext,
component_registry: ComponentRegistry,
health_handle: Health,
dispatcher: EventsDispatcher,
supervisor_handle: SupervisorHandle,
) -> Self
pub fn new( topology_context: &TopologyContext, component_context: &ComponentContext, component_registry: ComponentRegistry, health_handle: Health, dispatcher: EventsDispatcher, supervisor_handle: SupervisorHandle, ) -> Self
Creates a new SourceContext.
Sourcepub fn take_shutdown_handle(&mut self) -> ShutdownHandle
pub fn take_shutdown_handle(&mut self) -> ShutdownHandle
Consumes the shutdown handle of this source context.
Panics
Panics if the shutdown handle has already been taken.
Sourcepub fn take_health_handle(&mut self) -> Health
pub fn take_health_handle(&mut self) -> Health
Consumes the health handle of this source context.
Panics
Panics if the health handle has already been taken.
Sourcepub fn topology_context(&self) -> &TopologyContext
pub fn topology_context(&self) -> &TopologyContext
Gets a reference to the topology context.
Sourcepub fn component_context(&self) -> &ComponentContext
pub fn component_context(&self) -> &ComponentContext
Gets a reference to the component context.
Sourcepub fn component_registry(&self) -> &ComponentRegistry
pub fn component_registry(&self) -> &ComponentRegistry
Gets a reference to the component registry.
Sourcepub fn dispatcher(&self) -> &EventsDispatcher
pub fn dispatcher(&self) -> &EventsDispatcher
Gets a reference to the events dispatcher.
Sourcepub fn spawn_handle(&self) -> &SupervisorHandle
pub fn spawn_handle(&self) -> &SupervisorHandle
Returns a handle to the supervisor that this component is spawned on.
Dynamic child processes can be spawned via the supervisor handle and thus have their lifecycle coupled to the component itself: if the component restarts, or the component’s supervisor dies, the dynamic child processes will also be terminated automatically as well.